@@ -115,7 +115,7 @@ def persist_messages(collection: StandardCollection, messages: io.TextIOWrapper,
                 rec = o['record']
                 try:
                     logger.info("Debug Record before %s", rec)
-                    kps = key_properties.get('stream')
+                    kps = key_properties.get(stream)
                     _key = None
                     # Appending _ to keys inorder for preserving values of reserved keys in source data
                     reserved_keys = ['_key', '_id', '_rev']
